@@ -11,7 +11,7 @@ use Scalar::Util qw/refaddr/;
 
 our $QUIET_MODE;
 
-our $VERSION = '0.074_03'; # TRIAL VERSION
+our $VERSION = '0.0547_01'; # VERSION
 
 has [qw/source type/] => ( is => 'rw', required => 1 );
 
@@ -81,8 +81,6 @@ sub parent_ids { return shift->_attr_list('Parent', @_); }
 
 sub parent_id { return shift->_attr_single( { name => 'Parent' } ); }
 
-sub attr_replace { return shift->replace_attr(@_) }
-
 sub replace_attr {
   my ( $self, $name, @values ) = @_;
 
