@@ -9,16 +9,12 @@ use 5.010;
 use base 'Exporter';
 use Bio::Gonzales::Util::File qw/basename regex_glob is_archive/;
 use List::Util qw/min max/;
-use File::Temp qw/tempdir tempfile mktemp/;
+use File::Temp qw/tempdir tempfile/;
 use Bio::Gonzales::Seq::IO qw(faiterate faspew);
-use Capture::Tiny qw/capture_merged/;
-use Path::Tiny;
-use File::Spec::Functions qw/catfile/;
-use String::ShellQuote;
 
 use Params::Validate qw/validate/;
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.074_03'; # TRIAL VERSION
+our $VERSION = '0.0547_01'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -38,30 +34,23 @@ sub makeblastdb {
     }
   );
 
-  $c{wd} ||= './';
   my $unlink;
-  my $seqf     = shell_quote( $c{seq_file} );
-  my $basename = basename( $c{seq_file} );
-  if ( my $type = is_archive($seqf) ) {
+  my $seqf = $c{seq_file};
+  if ( is_archive($seqf) ) {
     say STDERR "$seqf is an archive, extracting first ...";
-
-    my $tmp_f = mktemp( catfile( $c{wd}, 'tempXXXXXX' ) );
-
-    if ( $type eq 'gzip' or $type eq 'bgzf' ) {
-      system("gzip -dc <$seqf >$tmp_f") == 0 or die "system failed: $?";
-    } elsif ( $type eq 'bzip2' ) {
-      system("bzip2 -dc <$seqf >$tmp_f") == 0 or die "system failed: $?";
-    } else {
-      confess("archive type $type not supported");
+    my $fait = faiterate($seqf);
+    my ( $fh, $fn ) = tempfile();
+    while ( my $s = $fait->() ) {
+      faspew( $fh, $s );
     }
-
+    $fh->close;
     $unlink = 1;
-    $seqf   = $tmp_f;
+    $seqf   = $fn;
     say STDERR "extraction finished. making blast DB";
-    $basename = basename($basename);    # remove 2nd extension, e.g. a.fa.gz -> a.fa -> a
   }
 
-  my @cmd = 'makeblastdb';
+  my $basename = basename( $c{seq_file} );
+  my @cmd      = 'makeblastdb';
   push @cmd, '-in',    $seqf;
   push @cmd, '-title', $basename;
   push @cmd, '-parse_seqids' if ( $c{parse_seqids} );
@@ -70,12 +59,13 @@ sub makeblastdb {
   if    ( $c{alphabet} =~ /^(?:a|p)/ )   { push @cmd, '-dbtype', 'prot' }
   elsif ( $c{alphabet} =~ /^(?:n|d|r)/ ) { push @cmd, '-dbtype', 'nucl' }
 
+  $c{wd} //= './';
   $c{db_prefix} //= $basename;
   $c{db_prefix} .= '.bdb';
   my $db_name = File::Spec->catfile( $c{wd}, $c{db_prefix} );
   push @cmd, '-out', $db_name;
 
-  my @existing_db_files = regex_glob( $c{wd}, qr/^\Q$c{db_prefix}.\E[np]\w\w$/ );
+  my @existing_db_files = regex_glob( $c{wd}, qr/^\Q$c{db_prefix}.\En\w\w$/ );
   if ( @existing_db_files > 0 ) {
     my $oldest_db_file_age = min( map { ( stat $_ )[9] } @existing_db_files );
     my $seq_file_age = ( stat $c{seq_file} )[9];
@@ -90,10 +80,9 @@ sub makeblastdb {
 
   say STDERR "Creating blast db:";
   say STDERR join " ", @cmd;
-
-  my $merged = capture_merged { system(@cmd) };
-
-  say STDERR $merged;
+  local *STDERR;
+  local *STDOUT;
+  system @cmd;
 
   unlink $seqf if ($unlink);
   return $db_name;
