@@ -1,18 +1,13 @@
 package Bio::Gonzales::Seq;
 
-use v5.10;
-
 use Mouse;
 
 use overload '""' => 'all';
 use Carp;
 use Data::Dumper;
-use Digest::SHA1 qw/sha1_hex/;
-use Digest::MD5 qw/md5_hex/;
-use Digest::SHA2;
+use Bio::Gonzales::Seq::IO;
 
-our $WIDTH = 80;
-our $VERSION = '0.074_03'; # TRIAL VERSION
+our $VERSION = '0.0547_01'; # VERSION
 
 has id     => ( is => 'rw', required   => 1 );
 has desc   => ( is => 'rw', default    => '' );
@@ -27,8 +22,6 @@ sub _build_gaps {
   return $gaps;
 }
 
-sub ungapped_seq { return shift->gapless_seq(@_); }
-
 sub _build_length {
   return CORE::length( shift->seq() );
 }
@@ -55,23 +48,6 @@ sub BUILDARGS {
   return \%a;
 }
 
-sub as_hash {
-  my $self = shift;
-  return { id => $self->id, desc => $self->desc, seq => $self->seq, info => $self->info };
-}
-
-sub Format_seq_string {
-  my ( $str, $width ) = @_;
-  $width //= $WIDTH;
-
-  if ( defined $str && length($str) > 0 ) {
-    $str =~ tr/ \t\n\r//d;    # Remove whitespace and numbers
-    $str =~ s/\d+//g;
-    $str =~ s/(.{1,$width})/$1\n/g;
-    return $str;
-  }
-}
-
 sub def {
   my ($self) = @_;
 
@@ -107,40 +83,31 @@ around 'seq' => sub {
 };
 
 sub gapless_seq {
-  ( my $seq = shift->seq ) =~ tr/-.//d;
+  my ($self) = @_;
+
+  my $seq = $self->seq;
+  $seq =~ tr/-.//d;
   return $seq;
 }
 
 sub rm_gaps {
   my ($self) = @_;
-
-  $self->seq( $self->gapless_seq );
+  
+  $self->seq($self->gapless_seq);
   return $self;
 }
 
 sub clone {
   my ($self) = @_;
 
-  return __PACKAGE__->new(
-    id    => $self->id,
-    desc  => $self->desc,
-    seq   => $self->seq,
-    delim => $self->delim,
-    info  => $self->info
-  );
+  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => $self->seq, delim => $self->delim );
   #shift->clone_object(@_)
 }
 
 sub clone_empty {
   my ($self) = @_;
 
-  return __PACKAGE__->new(
-    id    => $self->id,
-    desc  => $self->desc,
-    seq   => '',
-    delim => $self->delim,
-    info  => $self->info
-  );
+  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => '', delim => $self->delim );
 }
 
 sub display_id { shift->id(@_) }
@@ -153,30 +120,25 @@ sub ungapped_length {
 
 sub sequence { shift->seq(@_) }
 
-sub stringify {
+sub all {
   my ($self) = @_;
 
   return ">" . $self->id . ( $self->desc ? $self->delim . $self->desc : "" ) . "\n" . $self->seq . "\n";
 }
 
-sub all { shift->stringify(@_) }
-
-sub all_formatted { shift->stringify_pretty(@_) }
-
-sub stringify_pretty {
-  my ( $self, $width ) = @_;
-  $width //= $WIDTH;
+sub all_formatted {
+  my ($self) = @_;
 
   return
       ">"
     . $self->id
     . ( $self->desc ? $self->delim . $self->desc : "" ) . "\n"
-    . Format_seq_string( $self->seq );
+    . Bio::Gonzales::Seq::IO::format_seq_string( $self->seq );
 }
 
-sub all_pretty { shift->stringify_pretty(@_) }
+sub all_pretty { shift->all_formatted(@_) }
 
-sub pretty { shift->stringify_pretty(@_) }
+sub pretty { shift->all_formatted(@_) }
 
 sub as_primaryseq {
   my ($self) = @_;
@@ -232,16 +194,9 @@ sub revcom {
   return $self;
 }
 
-sub revcom_seq {
-  my $self = shift;
-  return _revcom_from_string( $self->seq, $self->guess_alphabet );
-}
-
 sub subseq {
   my ( $self, $range, $c ) = @_;
 
-  $range = [ $range->start, $range->end, $range->strand ]
-    if ( blessed($range) && $range->isa('Bio::Gonzales::Feat') );
   my ( $seq, $corrected_range ) = $self->subseq_as_string( $range, $c );
   my ( $b, $e, $strand, @rest ) = @$corrected_range;
 
@@ -266,21 +221,6 @@ sub subseq {
   return $new_seq;
 }
 
-sub sha1_checksum {
-  return sha1_hex( shift->seq );
-}
-
-sub md5_checksum {
-  return md5_hex( shift->seq );
-}
-
-sub sha512_checksum {
-  my $self = shift;
-  my $sha2 = Digest::SHA2->new(512);
-  $sha2->add( $self->seq );
-  return $sha2->hexdigest;
-}
-
 sub subseq_as_string {
   my ( $self, $range, $c ) = @_;
 
@@ -290,7 +230,7 @@ sub subseq_as_string {
   if ( $c->{relaxed_range} ) {
     #if b or e are not defined, just take the beginning and end as given
     #warn "requested invalid subseq range ($b,$e;$strand) from " . $self->id . ", using relaxed boundaries."
-    #unless ( $b && $e );
+      #unless ( $b && $e );
     $b ||= '^';
     $e ||= '$';
   }
@@ -332,39 +272,39 @@ sub subseq_as_string {
         if ( $seq =~ /[^AGCTN]/i );
     }
 
-    $seq = _revcom_from_string( $seq, $self->guess_alphabet );
+    $seq = _revcom_from_string($seq, $self->_guess_alphabet);
   }
 
   return wantarray ? ( $seq, [ $b, $e, $strand, @rest ] ) : $seq;
 }
 
 sub _revcom_from_string {
-  my ( $string, $alphabet ) = @_;
+   my ($string, $alphabet) = @_;
 
-  # Check that reverse-complementing makes sense
-  if ( $alphabet eq 'protein' ) {
-    confess("Sequence is a protein. Cannot revcom.");
-  }
-  if ( $alphabet ne 'dna' && $alphabet ne 'rna' ) {
-    carp "Sequence is not dna or rna, but [$alphabet]. Attempting to revcom, "
-      . "but unsure if this is right.";
-  }
+   # Check that reverse-complementing makes sense
+   if( $alphabet eq 'protein' ) {
+       confess("Sequence is a protein. Cannot revcom.");
+   }
+   if( $alphabet ne 'dna' && $alphabet ne 'rna' ) {
+      carp "Sequence is not dna or rna, but [$alphabet]. Attempting to revcom, ".
+                "but unsure if this is right.";
+   }
 
-  # If sequence is RNA, map to DNA (then map back later)
-  if ( $alphabet eq 'rna' ) {
-    $string =~ tr/uU/tT/;
-  }
+   # If sequence is RNA, map to DNA (then map back later)
+   if( $alphabet eq 'rna' ) {
+       $string =~ tr/uU/tT/;
+   }
 
-  # Reverse-complement now
-  $string =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
-  $string = CORE::reverse $string;
+   # Reverse-complement now
+   $string =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
+   $string = CORE::reverse $string;
 
-  # Map back RNA to DNA
-  if ( $alphabet eq 'rna' ) {
-    $string =~ tr/tT/uU/;
-  }
+   # Map back RNA to DNA
+   if( $alphabet eq 'rna' ) {
+       $string =~ tr/tT/uU/;
+   }
 
-  return $string;
+   return $string;
 }
 
 1;
