@@ -6,13 +6,10 @@ use Carp;
 
 use Scalar::Util qw/blessed/;
 use Data::Dumper;
-use Bio::Gonzales::Matrix::IO;
-use File::Which qw/which/;
-use Bio::Gonzales::Seq::IO;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.074_03'; # TRIAL VERSION
+our $VERSION = '0.0547_01'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -24,88 +21,8 @@ our $VERSION = '0.074_03'; # TRIAL VERSION
   pairwise_identities
   map_seqids
   seqid_mapper
-  crc64
-  strand_convert
-  seq_lengths
-  seq_apply
 );
 
-our %STRAND_CHAR_TABLE = (
-  '+' => 1,
-  '-' => -1,
-  '.' => 0,
-  -1  => '-',
-  1   => '+',
-  0   => '.',
-);
-
-our $BLASTDB_CMD  = which('blastdbcmd');
-our $SAMTOOLS_CMD = which('samtools');
-
-sub strand_convert {
-  if ( @_ && @_ > 0 && $_[-1] && exists( $STRAND_CHAR_TABLE{ $_[-1] } ) ) {
-    return $STRAND_CHAR_TABLE{ $_[-1] };
-  } else {
-    return '.';
-  }
-}
-
-sub seq_lengths {
-  my $f = shift;
-
-  my $d;
-  if ( -f $f . ".fai" ) {
-    $d = mslurp( $f . ".fai", { header => undef } );
-  } elsif ( -f $f . ".nhr" ) {
-    open my $fh, '-|', $BLASTDB_CMD, '-db', $f, '-entry', 'all', '-outfmt', "%a\t%l"
-      or die "Can't open filehandle: $!";
-    $d = mslurp( $fh, { header => undef } );
-    close $fh;
-  } elsif ($SAMTOOLS_CMD) {
-    system( 'samtools', 'faidx', $f ) == 0 or die "system failed: $?";
-    $d = mslurp( $f . ".fai", { header => undef } ) if ( -f $f . ".fai" );
-  }
-
-  # nothing worked so far
-  unless ($d) {
-    say STDERR "could not use samtools or blast indices, using std method";
-    my @lengths;
-    my $fit = faiterate($f);
-    while ( my $seq = $fit->() ) {
-      push @lengths, [ $seq->id, $seq->length ];
-    }
-    $d = \@lengths;
-  }
-
-  my %sl;
-  for my $r (@$d) {
-    die "double ID" if ( $sl{ $r->[0] } );
-    $sl{ $r->[0] } = $r->[1];
-  }
-
-  return \%sl;
-}
-
-sub seq_apply {
-  my ( $f, $sub, $pattern ) = @_;
-
-  die "file or sub ref not correct" unless ( ref $sub eq 'CODE' && -f $f );
-  my $seq_lengths = seq_lengths($f);
-  my @res;
-  my $num = keys %$seq_lengths;
-  for my $sid ( keys %$seq_lengths ) {
-    my $spat;
-    if ($pattern) {
-      $spat = $pattern;
-      $spat =~ s/\{id\}/$sid/g;
-      $spat =~ s/\{begin\}/1/g;
-      $spat =~ s/\{end\}/$seq_lengths->{$sid}/g;
-    }
-    push @res, $sub->( { id => $sid, begin => 1, end => $seq_lengths->{$sid}, num => $num }, $spat );
-  }
-  return \@res;
-}
-
 sub pairwise_identity_l {
   my ( $seq1, $seq2 ) = @_;
   return _pairwise_identity_generic( $seq1, $seq2, 1, 0 );
@@ -134,7 +51,7 @@ sub _pairwise_identity_generic {
     $seq2_gaps = () = $seq2 =~ /-/g;
   }
 
-  my $mask    = $seq1 ^ $seq2;
+  my $mask = $seq1 ^ $seq2;
   my $matches = $mask =~ tr/\x0/\x0/;
 
   my $longest;
@@ -237,45 +154,6 @@ sub seqid_mapper {
   };
 }
 
-{
-  my $POLY64REVh = 0xd8000000;
-  my @CRCTableh  = 256;
-  my @CRCTablel  = 256;
-  my $initialized;
-
-  sub crc64 {
-    my $sequence = shift;
-    my $crcl     = 0;
-    my $crch     = 0;
-    if ( !$initialized ) {
-      $initialized = 1;
-      for ( my $i = 0; $i < 256; $i++ ) {
-        my $partl = $i;
-        my $parth = 0;
-        for ( my $j = 0; $j < 8; $j++ ) {
-          my $rflag = $partl & 1;
-          $partl >>= 1;
-          $partl |= ( 1 << 31 ) if $parth & 1;
-          $parth >>= 1;
-          $parth ^= $POLY64REVh if $rflag;
-        }
-        $CRCTableh[$i] = $parth;
-        $CRCTablel[$i] = $partl;
-      }
-    }
-
-    foreach ( split '', $sequence ) {
-      my $shr        = ( $crch & 0xFF ) << 24;
-      my $temp1h     = $crch >> 8;
-      my $temp1l     = ( $crcl >> 8 ) | $shr;
-      my $tableindex = ( $crcl ^ ( unpack "C", $_ ) ) & 0xFF;
-      $crch = $temp1h ^ $CRCTableh[$tableindex];
-      $crcl = $temp1l ^ $CRCTablel[$tableindex];
-    }
-    return wantarray ? ( $crch, $crcl ) : sprintf( "%08X%08X", $crch, $crcl );
-  }
-}
-
 1;
 __END__
 
