@@ -6,16 +6,13 @@ use warnings;
 use strict;
 use Carp;
 
-use String::ShellQuote;
-
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.074_03'; # TRIAL VERSION
+our $VERSION = '0.0547_01'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
-@EXPORT_OK
-  = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe sys_fmt sys_pipe_fatal deep_value);
+@EXPORT_OK   = qw(undef_slice slice invslice flatten hash_merge as_arrayref);
 
 sub slice {
   my ( $hr, @k ) = @_;
@@ -101,58 +98,6 @@ sub as_arrayref {
   }
 }
 
-sub sys_fmt {
-  my $cmd;
-
-  for my $e (@_) {
-    if ( ref $e eq 'ARRAY' ) {
-      $cmd .= shell_quote(@$e) . " ";
-    } elsif ( $e =~ /^>>|\d?>|<|<<|\||\d?>\&\d$/ ) {
-      $cmd .= $e . " ";
-    } elsif ( defined $e ) {
-      $cmd .= shell_quote($e) . " ";
-    } else {
-      next;
-    }
-  }
-  chomp $cmd;
-
-  return $cmd;
-}
-
-sub sys_pipe {
-  my $cmd = sys_fmt(@_);
-  system($cmd) == 0 or croak "system failed: $?\n$cmd";
-}
-
-sub sys_pipe_fatal {
-  my $cmd = 'set pipefail; ' . sys_fmt(@_);
-  system($cmd) == 0 or croak "system " . join( " ", @_ ) . " FAILED: $? ## $!";
-}
-
-sub deep_value {
-  my ( $data, $keys ) = ( shift, shift );
-
-  $keys = [$keys] if ( defined($keys) && !ref $keys );
-
-  for my $k (@$keys) {
-    my $type = ref $data;
-    if ( !$type ) {
-      die "key >$k< cannot be resolved (beyond max level)";
-    } elsif ( $type eq 'ARRAY' ) {
-      die "key >$k< cannot be resolved (non-existent)" unless ( exists( $data->[$k] ) );
-      $data = $data->[$k];
-    } elsif ( $type eq 'HASH' ) {
-      die "key >$k< cannot be resolved (non-existent)" unless ( exists( $data->{$k} ) );
-      $data = $data->{$k};
-    } elsif ( $type eq 'CODE' ) {
-      $data = $data->($k);
-    } else {
-      croak "type $type not supported";
-    }
-  }
-  return $data;
-}
 1;
 
 __END__
