@@ -12,20 +12,6 @@ use IO::Zlib;
 use IO::Uncompress::Bunzip2 qw($Bunzip2Error);
 use File::Which qw/which/;
 use Bio::Gonzales::Util::IO::Compressed;
-use Tie::IxHash;
-
-our $ZIP_MAGIC = Tie::IxHash->new(
-  BGZF     => [ "\037\213\010\4\0\0\0\0\0\377\6\0\102\103\2\0", 'bgzip' ],
-  GZIP     => [ "\037\213",                                     'gzip' ],
-  COMPRESS => [ "\037\235",                                     'gzip' ],
-  BZIP2    => [ "BZh",                                          'bzip2' ],
-  XZ       => [ "\xFD7zXZ",                                     'xz' ]
-);
-#{ ct_lzip,     4, "LZIP" },
-#{ ct_lzma,     6, "\xFFLZMA" },
-#{ ct_lzop,     4, "\211LZO" },
-
-#use constant BZIP2_MAGIC  => "\102\132\150";
 
 our %ZMODES = (
   '>'  => 'wb',
@@ -35,14 +21,14 @@ our %ZMODES = (
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.074_03'; # TRIAL VERSION
-our $EXTERNAL_GZ    = which('gzip');    #which('pigz') // which('gzip');
+our $VERSION = '0.0547_01'; # VERSION
+our $EXTERNAL_GZ = which('pigz') // which('gzip');
 our $EXTERNAL_BZIP2 = which('bzip2');
 
 @EXPORT      = qw(glob_regex epath bname openod spath);
 %EXPORT_TAGS = ();
 @EXPORT_OK
-  = qw(expand_path slurpc basename regex_glob open_on_demand is_newer splitpath %ZMODES is_archive expand_home gonzopen gz_type);
+  = qw(expand_path slurpc basename regex_glob open_on_demand is_newer splitpath %ZMODES is_archive expand_home);
 
 sub epath { expand_path(@_) }
 
@@ -112,9 +98,7 @@ sub splitpath {
   return ( $dir, $filename );
 }
 
-sub openod { confess "this function is deprecated, use gonzopen instead"; }
-
-sub gonzopen { ( my $fh ) = open_on_demand(@_); return $fh; }
+sub openod { return open_on_demand(@_) }
 
 sub open_on_demand {
   my ( $src, $mode ) = @_;
@@ -124,28 +108,19 @@ sub open_on_demand {
 
   my $fh;
   my $fh_was_open;
-
-  if ( $src && !ref($src) && $src eq '-' ) {
-    if ( $mode eq '<' ) {
-      $src = \*STDIN;
-    } elsif ( $mode eq '>' ) {
-      $src = \*STDOUT;
-    }
-  }
-
   if ( is_fh($src) ) {
     $fh          = $src;
     $fh_was_open = 1;
   } elsif ( !ref($src) ) {
     $src = expand_home($src);
-    if ( $src =~ /.+?\.b?gz$/i || ( $mode eq '<' && -e $src && gz_type($src) ) ) {
-      if ($EXTERNAL_GZ) {
+    if ( $src =~ /.+?\.gz$/i) {
+      if($EXTERNAL_GZ) {
         $fh = _pipe_z( $EXTERNAL_GZ, $src, $mode );
       } else {
         $fh = IO::Zlib->new( $src, $ZMODES{$mode} ) or die "IO::Zlib failed\n";
       }
-    } elsif ( $src =~ /.+?\.bz2$/i ) {
-      if ($EXTERNAL_BZIP2) {
+    } elsif ( $src =~ /.+?\.bz2$/i) {
+      if($EXTERNAL_BZIP2) {
         $fh = _pipe_z( $EXTERNAL_BZIP2, $src, $mode );
       } else {
         $fh = IO::Uncompress::Bunzip2->new($src) or die "IO::Uncompress::Bunzip2 failed: $Bunzip2Error\n";
@@ -168,8 +143,8 @@ sub open_on_demand {
 }
 
 sub _pipe_z {
-  my ( $gz, $f, $mode ) = @_;
-  return unless ( $gz && -x $gz );
+  my ($gz, $f, $mode ) = @_;
+  return unless( $gz && -x $gz);
   if ( $mode eq '<' ) {
     open my $fh, '-|', $gz, '-c', '-d', $f or die "Can't open filehandle $f: $!";
     return $fh;
@@ -177,12 +152,12 @@ sub _pipe_z {
     my ( $r, $w );
     pipe( $r, $w ) || die "gz pipe failed: $!";
     my $pid = fork();
-    #$SIG{PIPE} = sub { die "whoops, gz pipe broke" };
+    $SIG{PIPE} = sub { die "whoops, gz pipe broke" };
     defined($pid) || die "gz fork failed: $!";
     if ($pid) {
       $r->close;
       #return $w;
-      return Bio::Gonzales::Util::IO::Compressed->new( $w, $pid );
+      return Bio::Gonzales::Util::IO::Compressed->new($w, $pid);
     } else {
       open( STDIN, "<&", $r ) || die "can't reopen gz STDIN: $!";
       $w->close || die "can't close gz WRITER: $!";
@@ -197,20 +172,13 @@ sub _pipe_z {
 sub is_archive {
   my $f = shift;
 
-  open my $fh, '<', $f or die "Can't open filehandle: $!";
-  binmode $fh;
-  my $nread = read( $fh, my $buffer, 32 );
-  close $fh;
-
-  return unless ( $nread >= 4 );
-
-  for ( my $i = 0; $i < $ZIP_MAGIC->Length; $i++ ) {
-    my ($type)  = $ZIP_MAGIC->Keys($i);
-    my ($magic) = $ZIP_MAGIC->Values($i);
-    my $size    = length( $magic->[0] );
-    return lc($type) if ( unpack( 'H' . $size, $buffer ) eq unpack( 'H' . $size, $magic->[0] ) );
+  if ( $f =~ /.+?\.gz$/i ) {
+    return 'gz';
+  } elsif ( $f =~ /.+?\.bz2$/i ) {
+    return 'bz2';
+  } else {
+    return;
   }
-  return;
 }
 
 sub is_newer {
@@ -233,26 +201,6 @@ sub is_fh {
   return;
 }
 
-sub gz_type {
-  my $f = shift;
-
-  my ($magic) = $ZIP_MAGIC->Values( $ZIP_MAGIC->Indices("BGZF") );
-  open my $fh, '<', $f or die "Can't open filehandle: $!";
-  binmode $fh;
-  my $size = length( $magic->[0] );
-  my $nread = read( $fh, my $buffer, $size );
-  close $fh;
-  return unless ( $nread == $size );
-
-  if ( unpack( 'H' . $size, $buffer ) eq unpack( 'H' . $size, $magic->[0] ) ) {
-    return 'bgzf';
-  } elsif ( unpack( 'H2', $buffer ) eq unpack( 'H2', $magic->[0] ) ) {
-    return 'gzip';
-  } else {
-    return;
-  }
-}
-
 1;
 __END__
 
